@@ -58,12 +58,11 @@ void BitButton::paintEvent(QPaintEvent *) {
 // Name: KCalcBitset
 // Desc: constructor
 //------------------------------------------------------------------------------
-KCalcBitset::KCalcBitset(QWidget *parent) : QFrame(parent), value_(0) {
+KCalcBitset::KCalcBitset(QWidget *parent) : QFrame(parent), bit_button_group_(new QButtonGroup(this)), value_(0) {
 
 	setFrameStyle(QFrame::Panel | QFrame::Sunken);
-	
-	bit_button_group_ = new QButtonGroup(this);
-	connect(bit_button_group_, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &KCalcBitset::slotToggleBit);
+
+	connect(bit_button_group_, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &KCalcBitset::slotToggleBit);
 
 	// smaller label font
 	QFont fnt = font();
@@ -73,7 +72,7 @@ KCalcBitset::KCalcBitset(QWidget *parent) : QFrame(parent), value_(0) {
 
 	// main layout
 	QGridLayout *layout = new QGridLayout(this);
-	layout->setMargin(2);
+    layout->setContentsMargins(2, 2, 2, 2);
 	layout->setSpacing(0);
 
 	// create bits
@@ -82,7 +81,7 @@ KCalcBitset::KCalcBitset(QWidget *parent) : QFrame(parent), value_(0) {
 		for (int cols = 0; cols < 4; cols++) {
 			// two rows of four words
 			QHBoxLayout *const wordlayout = new QHBoxLayout();
-			wordlayout->setMargin(2);
+            wordlayout->setContentsMargins(2, 2, 2, 2);
 			wordlayout->setSpacing(2);
 			layout->addLayout(wordlayout, rows, cols);
 
