@@ -204,7 +204,7 @@ bool KCalcDisplay::sendEvent(Event event) {
 	case EventClear:
 	case EventReset:
 		display_amount_ = KNumber::Zero;
-		str_int_ = QLatin1String("0");
+		str_int_ = QStringLiteral("0");
 		str_int_exp_.clear();
 
 		eestate_ = false;
@@ -308,6 +308,17 @@ void KCalcDisplay::slotPaste(bool bClipboard) {
 		}
 	}
 
+	// for locales where the groups separator is not a comma (,) but a non breaking space
+	// accept (and correct) both decimal separators (comma and dot) for convenience
+	if (KNumber::decimalSeparator() == QChar::fromLatin1(',')
+			&& (
+				QLocale().groupSeparator() != QChar::fromLatin1(',')
+				&& QLocale().groupSeparator() != QChar::fromLatin1('.')
+				)
+			&& tmp_str.count(QChar::fromLatin1('.')) == 1) {
+		tmp_str = tmp_str.replace(QChar::fromLatin1('.'), QChar::fromLatin1(','));
+	}
+
 	if (tmp_num_base != NB_DECIMAL) {
 		bool was_ok;
 		const qint64 tmp_result = tmp_str.toULongLong(&was_ok, tmp_num_base);
@@ -473,7 +484,7 @@ bool KCalcDisplay::setAmount(const KNumber &new_amount) {
 
 	QString display_str;
 
-	str_int_ = QLatin1String("0");
+	str_int_ = QStringLiteral("0");
 	str_int_exp_.clear();
 	period_   = false;
 	neg_sign_ = false;
@@ -887,7 +898,7 @@ void KCalcDisplay::deleteLastDigit() {
 			if (length > 1) {
 				str_int_exp_.chop(1);
 			} else {
-				str_int_exp_ = QLatin1String((const char *)0);
+				str_int_exp_ = QLatin1String((const char *)nullptr);
 			}
 		}
 	} else {
@@ -972,7 +983,7 @@ void KCalcDisplay::paintEvent(QPaintEvent *) {
 	style()->drawPrimitive(QStyle::PE_PanelLineEdit, &option, &painter, this);
 
 	// draw display text
-	const int margin = style()->pixelMetric(QStyle::PM_DefaultFrameWidth, 0, 0);
+	const int margin = style()->pixelMetric(QStyle::PM_DefaultFrameWidth, nullptr, nullptr);
 	QRect cr = contentsRect();
 	cr.adjust(margin*2, 0, -margin*2, 0);   // provide a margin
 	
@@ -986,7 +997,7 @@ void KCalcDisplay::paintEvent(QPaintEvent *) {
 	painter.setFont(fnt);
 	
 	QFontMetrics fm(fnt);
-	const uint w = fm.width(QLatin1String("________"));
+	const uint w = fm.width(QStringLiteral("________"));
 	const uint h = fm.height();
 
 	for (int n = 0; n < NUM_STATUS_TEXT; ++n) {
